pub struct ZkStackService { /* private fields */ }Expand description
“Manager” class for a set of tasks. Collects all the resources and tasks, then runs tasks until completion.
Implementations
Sourceimpl ZkStackService
impl ZkStackService
Sourcepub fn run<G>(self, observability_guard: G) -> Result<(), ZkStackServiceError>
pub fn run<G>(self, observability_guard: G) -> Result<(), ZkStackServiceError>
Runs the system.
In case of errors during wiring phase, will return the list of all the errors that happened, in the order of their occurrence.
observability_guard, if provided, will be used to deinitialize the observability subsystem
as the very last step before exiting the node.